'use strict'
path = require('path')
webpack = require('webpack')
autoprefixer = require('autoprefixer')
extractTextPlugin = require('extract-text-webpack-plugin')

module.exports =
  debug: false
  resolve:
    root: __dirname
    modulesDirectories: ['node_modules']
    extensions: [
      ''
      '.cjsx'
      '.coffee'
      '.jsx'
      '.js'
    ]
    alias:
      underscore: 'lodash'
      source: path.join(__dirname, '/src/main')
  entry:
    main: [
      'source/cjsx/main'
    ]
    vendor: [
      'normalize.css/normalize.css'
      'es5-shim'
      'es5-shim/es5-sham'
      'es6-shim'
      'es6-shim/es6-sham'
      'json3'
      'html5shiv'
      'html5shiv/dist/html5shiv-printshiv'
    ]
  output:
    path: path.join(__dirname, './assets')
    filename: '[name].js'
#    filename: "[name]-[chunkhash].js"
#    chunkFilename: "[name]-[chunkhash].js"
    publicPath: '/assets/'
    pathinfo: false
  plugins: [
    new (webpack.PrefetchPlugin)("react")
    new (webpack.PrefetchPlugin)("react/lib/ReactComponentBrowserEnvironment")
    new (extractTextPlugin)('[name].css', { allChunks: true })
    new (webpack.NoErrorsPlugin)
    new (webpack.optimize.DedupePlugin),
    new (webpack.optimize.OccurrenceOrderPlugin)(true)
    new (webpack.optimize.UglifyJsPlugin)(
      sourceMap: true
      mangle:
        except: [
          '$super'
          '$'
          '_'
          'exports'
          'require'
        ]
      minimize: true
      output:
        comments: false
      compress:
        warnings: false
    )
  ]
  module:
    preLoaders: [
        test: /\.(js|jsx)$/
        loader: 'eslint'
        exclude: /node_modules/
     ]
    loaders: [
        test: /\.(js|jsx)?$/
        exclude: /(node_modules|bower_components)/
        loader: [
          'babel'
        ]#'babel-loader' is also a legal name to reference
        query:
          presets: ['es2015']
          plugins: ['transform-runtime']
      ,
        test: /\.cjsx$/
        loaders: [
            'coffee'
            'cjsx'
        ]#'babel-loader' is also a legal name to reference
      ,
      test: /\.coffee$/
      loader: 'coffee'
    ,
      test: /\.scss$/
      loader: extractTextPlugin.extract('style', 'css?minimize!postcss!sass')
    ,
      test: /\.css$/
      exclude: /.*\.min.css/
      loader: extractTextPlugin.extract('style', 'css?minimize!postcss')
    ,
      test: /\.png$/
      loader: 'url?limit=8192&mimetype=image/png'
    ,
      test: /\.jpe?g$/
      loader: 'url?limit=8192&mimetype=image/jpg'
    ,
      test: /\.gif$/
      loader: 'url?limit=8192&mimetype=image/gif'
    ,
      test: /\.svg(\?v=\d+\.\d+\.\d+)?$/
      loader: 'url?limit=8192&mimetype=image/svg+xml'
    ,
      test: /\.woff2(\?v=\d+\.\d+\.\d+)?$/
      loader: 'url?limit=8192&mimetype=application/font-woff2'
    ,
      test: /\.woff(\?v=\d+\.\d+\.\d+)?$/
      loader: 'url?limit=8192&mimetype=application/font-woff'
    ,
      test: /\.ttf(\?v=\d+\.\d+\.\d+)?$/
      loader: 'url?limit=8192&mimetype=application/octet-stream'
    ,
      test: /\.eot(\?v=\d+\.\d+\.\d+)?$/
      loader: 'file'
    ]
  postcss: [ autoprefixer ]
  eslint:
    emitErrors: true
    reporter: (results) ->
      results.map((result) ->
        result.messages.map((msg) ->
          ' ' + msg.message + '(' + msg.ruleId + ')' + ' @ line ' + msg.line + ' column ' + msg.column + ' - ' + (if msg.fatal then 'fatal, ' else '') + 'severity: ' + msg.severity
        ).join '\n'
      ).join '\n'
